@@ -7,9 +7,12 @@ import (
 func (c *Client) GetCurrentUser(ctx context.Context) (*User, error) {
 	query := `
 		query {
-			viewer {
-				email
-			}
+				viewer {
+					... on User {
+						email
+						enablePaidHobby
+					}
+				}
 		}
 	`
 
