@@ -54,6 +54,7 @@ type MachineDeploymentArgs struct {
 	ExcludeRegions         map[string]interface{}
 	OnlyRegions            map[string]interface{}
 	ImmediateMaxConcurrent int
+	VolumeInitialSize      int
 }
 
 type machineDeployment struct {
@@ -87,6 +88,7 @@ type machineDeployment struct {
 	excludeRegions         map[string]interface{}
 	onlyRegions            map[string]interface{}
 	immediateMaxConcurrent int
+	volumeInitialSize      int
 }
 
 func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (MachineDeployment, error) {
@@ -147,6 +149,10 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	if immedateMaxConcurrent < 1 {
 		immedateMaxConcurrent = 1
 	}
+	volumeInitialSize := 1
+	if args.VolumeInitialSize > 0 {
+		volumeInitialSize = args.VolumeInitialSize
+	}
 
 	md := &machineDeployment{
 		apiClient:              apiClient,
@@ -172,6 +178,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 		excludeRegions:         args.ExcludeRegions,
 		onlyRegions:            args.OnlyRegions,
 		immediateMaxConcurrent: immedateMaxConcurrent,
+		volumeInitialSize:      volumeInitialSize,
 	}
 	if err := md.setStrategy(); err != nil {
 		return nil, err
