@@ -181,9 +181,6 @@ func newRun() *cobra.Command {
 			Shorthand:   "v",
 			Description: "Volumes to mount in the form of <volume_id_or_name>:/path/inside/machine[:<options>]",
 		},
-		flag.String{
-			Name: "host-dedication-id",
-		},
 		flag.Bool{
 			Name:        "lsvd",
 			Description: "Enable LSVD for this machine",
@@ -244,10 +241,9 @@ func runMachineRun(ctx context.Context) error {
 	}
 
 	input := api.LaunchMachineInput{
-		Name:             flag.GetString(ctx, "name"),
-		Region:           flag.GetString(ctx, "region"),
-		HostDedicationID: flag.GetString(ctx, "host-dedication-id"),
-		LSVD:             flag.GetBool(ctx, "lsvd"),
+		Name:   flag.GetString(ctx, "name"),
+		Region: flag.GetString(ctx, "region"),
+		LSVD:   flag.GetBool(ctx, "lsvd"),
 	}
 
 	flapsClient, err := flaps.New(ctx, app)
